@@ -1,19 +1,16 @@
-/*global URLify*/
 (function($) {
-    'use strict';
-    $.fn.prepopulate = function(dependencies, maxLength, allowUnicode) {
+    $.fn.prepopulate = function(dependencies, maxLength) {
         /*
             Depends on urlify.js
             Populates a selected field with the values of the dependent fields,
             URLifies and shortens the string.
             dependencies - array of dependent fields ids
             maxLength - maximum length of the URLify'd string
-            allowUnicode - Unicode support of the URLify'd string
         */
         return this.each(function() {
             var prepopulatedField = $(this);
 
-            var populate = function() {
+            var populate = function () {
                 // Bail if the field's value has been changed by the user
                 if (prepopulatedField.data('_changed')) {
                     return;
@@ -26,16 +23,16 @@
                         values.push(field.val());
                     }
                 });
-                prepopulatedField.val(URLify(values.join(' '), maxLength, allowUnicode));
+                prepopulatedField.val(URLify(values.join(' '), maxLength));
             };
 
             prepopulatedField.data('_changed', false);
-            prepopulatedField.on('change', function() {
+            prepopulatedField.change(function() {
                 prepopulatedField.data('_changed', true);
             });
 
             if (!prepopulatedField.val()) {
-                $(dependencies.join(',')).on('keyup change focus', populate);
+                $(dependencies.join(',')).keyup(populate).change(populate).focus(populate);
             }
         });
     };
