@@ -4,34 +4,32 @@ from django.contrib.postgres import forms, lookups
 from django.contrib.postgres.fields.array import ArrayField
 from django.core import exceptions
 from django.db.models import Field, TextField, Transform
-from django.utils.translation import gettext_lazy as _
-
-from .mixins import CheckFieldDefaultMixin
+from django.utils import six
+from django.utils.translation import ugettext_lazy as _
 
 __all__ = ['HStoreField']
 
 
-class HStoreField(CheckFieldDefaultMixin, Field):
+class HStoreField(Field):
     empty_strings_allowed = False
-    description = _('Map of strings to strings/nulls')
+    description = _('Map of strings to strings')
     default_error_messages = {
-        'not_a_string': _('The value of "%(key)s" is not a string or null.'),
+        'not_a_string': _('The value of "%(key)s" is not a string.'),
     }
-    _default_hint = ('dict', '{}')
 
     def db_type(self, connection):
         return 'hstore'
 
     def get_transform(self, name):
-        transform = super().get_transform(name)
+        transform = super(HStoreField, self).get_transform(name)
         if transform:
             return transform
         return KeyTransformFactory(name)
 
     def validate(self, value, model_instance):
-        super().validate(value, model_instance)
+        super(HStoreField, self).validate(value, model_instance)
         for key, val in value.items():
-            if not isinstance(val, str) and val is not None:
+            if not isinstance(val, six.string_types):
                 raise exceptions.ValidationError(
                     self.error_messages['not_a_string'],
                     code='not_a_string',
@@ -39,57 +37,51 @@ class HStoreField(CheckFieldDefaultMixin, Field):
                 )
 
     def to_python(self, value):
-        if isinstance(value, str):
+        if isinstance(value, six.string_types):
             value = json.loads(value)
         return value
 
     def value_to_string(self, obj):
-        return json.dumps(self.value_from_object(obj))
+        value = self._get_val_from_obj(obj)
+        return json.dumps(value)
 
     def formfield(self, **kwargs):
-        return super().formfield(**{
+        defaults = {
             'form_class': forms.HStoreField,
-            **kwargs,
-        })
-
-    def get_prep_value(self, value):
-        value = super().get_prep_value(value)
-
-        if isinstance(value, dict):
-            prep_value = {}
-            for key, val in value.items():
-                key = str(key)
-                if val is not None:
-                    val = str(val)
-                prep_value[key] = val
-            value = prep_value
-
-        if isinstance(value, list):
-            value = [str(item) for item in value]
-
-        return value
+        }
+        defaults.update(kwargs)
+        return super(HStoreField, self).formfield(**defaults)
 
 
 HStoreField.register_lookup(lookups.DataContains)
 HStoreField.register_lookup(lookups.ContainedBy)
-HStoreField.register_lookup(lookups.HasKey)
-HStoreField.register_lookup(lookups.HasKeys)
-HStoreField.register_lookup(lookups.HasAnyKeys)
+
+
+@HStoreField.register_lookup
+class HasKeyLookup(lookups.PostgresSimpleLookup):
+    lookup_name = 'has_key'
+    operator = '?'
+
+
+@HStoreField.register_lookup
+class HasKeysLookup(lookups.PostgresSimpleLookup):
+    lookup_name = 'has_keys'
+    operator = '?&'
 
 
 class KeyTransform(Transform):
     output_field = TextField()
 
     def __init__(self, key_name, *args, **kwargs):
-        super().__init__(*args, **kwargs)
+        super(KeyTransform, self).__init__(*args, **kwargs)
         self.key_name = key_name
 
     def as_sql(self, compiler, connection):
         lhs, params = compiler.compile(self.lhs)
-        return '(%s -> %%s)' % lhs, params + [self.key_name]
+        return "(%s -> '%s')" % (lhs, self.key_name), params
 
 
-class KeyTransformFactory:
+class KeyTransformFactory(object):
 
     def __init__(self, key_name):
         self.key_name = key_name
@@ -99,14 +91,14 @@ class KeyTransformFactory:
 
 
 @HStoreField.register_lookup
-class KeysTransform(Transform):
+class KeysTransform(lookups.FunctionTransform):
     lookup_name = 'keys'
     function = 'akeys'
     output_field = ArrayField(TextField())
 
 
 @HStoreField.register_lookup
-class ValuesTransform(Transform):
+class ValuesTransform(lookups.FunctionTransform):
     lookup_name = 'values'
     function = 'avals'
     output_field = ArrayField(TextField())
